import pandas as pd
import numpy as np

from pgmpy.models import BayesianModel
from pgmpy.estimators import HillClimbSearch, K2Score, BicScore
from pgmpy.sampling.Sampling import BayesianModelSampling
from pgmpy.factors.discrete.CPD import TabularCPD

data = pd.DataFrame.from_csv('crash_sample.csv', index_col=None)
nodes = list(data.columns)

# domain: car crash death rate
# samples: daily summaries of traffic and car crash records
# variables (network nodes):

# AvgSpeed -- the average travel speed (low high)
# Country -- the country/region that provides the summary (US UK Europe)
# DangerLvl -- aggregate crash danger estimate (unknown ingredients) (low high)
# NoAccidents -- the number of accidents (low medium high)
# NoFatalities -- the number of fatalities for the given traffic day (low medium high)
# NoJourneys -- the number of journeys made (low high)
# PoliceActivity -- activity resulting from a car accident fighting police action? (regular increased)
# RoadCond-- the conditions of roads (bad good)
# Season -- the period of a year (winter spring summer fall)
# Weather -- weather conditions (bad good)
# Weekend -- day type (working weekend holiday)


cat_to_num = {'AvgSpeed' : {'low' :0, 'high':1}, \
	      'Country' : {'US':0, 'UK':1, 'Europe':2}, \
	      'DangerLvl' : {'low':0, 'high':1}, \
	      'NoAccidents' : {'low':0, 'medium':1, 'high':2}, \
	      'NoFatalities' : {'low':0, 'medium':1, 'high':2}, \
	      'NoJourneys' : {'low':0, 'medium':1, 'high':2}, \
	      'PoliceActivity' : {'regular':0, 'increased':1}, \
	      'RoadCond' : {'bad':0,'good':1}, \
	      'Season' : {'winter':0, 'spring':1, 'summer':2, 'fall':3}, \
              'Weather' : {'bad':0, 'good':1}, \
              'Weekend' : {'working':0, 'weekend':1, 'holiday':2},
             }

num_to_cat = {}
for k1,v1 in cat_to_num.items():
    num_to_cat[k1] = { v2 : k2 for k2, v2 in v1.items()}

# select rows with missing data only
# data[data.isnull().any(axis=1)]

# get count of each combination in the data
# data.groupby(nodes).size()

# replace strings with numbers and back
# data.replace(num_to_cat).replace(cat_to_num)

